@@ -2,7 +2,7 @@ GQuark  bd_crypto_error_quark (void) {
         return g_quark_from_static_string ("g-bd-crypto-error-quark");
 }
 
-static const gchar const * const crypto_functions[] = {
+static const gchar* const crypto_functions[] = {
     "bd_crypto_is_tech_avail",
     "bd_crypto_generate_backup_passphrase",
     "bd_crypto_device_is_luks",
@@ -25,7 +25,7 @@ static const gchar const * const crypto_functions[] = {
     "bd_crypto_escrow_device",
     NULL};
 
-gchar const * const * get_crypto_functions (void) {
+const gchar* const* get_crypto_functions (void) {
     return crypto_functions;
 }
 
